from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AchannelCls:
	"""Achannel commands group definition. 7 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("achannel", core, parent)

	@property
	def result(self):
		"""result commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_result'):
			from .Result import ResultCls
			self._result = ResultCls(self._core, self._cmd_group)
		return self._result

	@property
	def relative(self):
		"""relative commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_relative'):
			from .Relative import RelativeCls
			self._relative = RelativeCls(self._core, self._cmd_group)
		return self._relative

	@property
	def absolute(self):
		"""absolute commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_absolute'):
			from .Absolute import AbsoluteCls
			self._absolute = AbsoluteCls(self._core, self._cmd_group)
		return self._absolute

	def clone(self) -> 'AchannelCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AchannelCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, ref_channel: enums.RefChannel) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:REFerence:TXCHannel:AUTO \n
		Snippet: driver.sense.power.achannel.reference.txChannel.auto.set(ref_channel = enums.RefChannel.LHIGhest) \n
		No command help available \n
			:param ref_channel: No help available
		"""
		param = Conversions.enum_scalar_to_str(ref_channel, enums.RefChannel)
		self._core.io.write(f'SENSe:POWer:ACHannel:REFerence:TXCHannel:AUTO {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OffsetCls:
	"""Offset commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offset", core, parent)

	@property
	def begin(self):
		"""begin commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_begin'):
			from .Begin import BeginCls
			self._begin = BeginCls(self._core, self._cmd_group)
		return self._begin

	@property
	def end(self):
		"""end commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_end'):
			from .End import EndCls
			self._end = EndCls(self._core, self._cmd_group)
		return self._end

	def clone(self) -> 'OffsetCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = OffsetCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ServiceCls:
	"""Service commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("service", core, parent)

	def get(self) -> bytes:
		"""SCPI: DIAGnostic:HUMS:SERVice \n
		Snippet: value: bytes = driver.diagnostic.hums.service.get() \n
		No command help available \n
			:return: service_info: No help available"""
		response = self._core.io.query_bin_block_ERROR(f'DIAGnostic:HUMS:SERVice?')
		return response



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CountCls:
	"""Count commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	def set(self, arg_0: float, powerMeter=repcap.PowerMeter.Default) -> None:
		"""SCPI: [SENSe]:PMETer<p>:MTIMe:AVERage:COUNt \n
		Snippet: driver.applications.k50Spurious.sense.pmeter.mtime.average.count.set(arg_0 = 1.0, powerMeter = repcap.PowerMeter.Default) \n
		This command sets the number of power readings included in the averaging process of power sensor measurements. Extended
		averaging yields more stable results for power sensor measurements, especially for measurements on signals with a low
		power, because it minimizes the effects of noise. \n
			:param arg_0: No help available
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
		"""
		param = Conversions.decimal_value_to_str(arg_0)
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		self._core.io.write(f'SENSe:PMETer{powerMeter_cmd_val}:MTIMe:AVERage:COUNt {param}')

	def get(self, powerMeter=repcap.PowerMeter.Default) -> float:
		"""SCPI: [SENSe]:PMETer<p>:MTIMe:AVERage:COUNt \n
		Snippet: value: float = driver.applications.k50Spurious.sense.pmeter.mtime.average.count.get(powerMeter = repcap.PowerMeter.Default) \n
		This command sets the number of power readings included in the averaging process of power sensor measurements. Extended
		averaging yields more stable results for power sensor measurements, especially for measurements on signals with a low
		power, because it minimizes the effects of noise. \n
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
			:return: arg_0: No help available"""
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		response = self._core.io.query_str(f'SENSe:PMETer{powerMeter_cmd_val}:MTIMe:AVERage:COUNt?')
		return Conversions.str_to_float(response)



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CatalogCls:
	"""Catalog commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("catalog", core, parent)

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Used_Disk_Space: int: No parameter help available
			- Free_Disk_Space: int: No parameter help available
			- File_Size: List[int]: No parameter help available
			- Filename: List[str]: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_int('Used_Disk_Space'),
			ArgStruct.scalar_int('Free_Disk_Space'),
			ArgStruct('File_Size', DataType.IntegerList, None, False, True, 1),
			ArgStruct('Filename', DataType.StringList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Used_Disk_Space: int = None
			self.Free_Disk_Space: int = None
			self.File_Size: List[int] = None
			self.Filename: List[str] = None

	def get(self) -> GetStruct:
		"""SCPI: [SENSe]:CORRection:TRANsducer:CATalog \n
		Snippet: value: GetStruct = driver.sense.correction.transducer.catalog.get() \n
		No command help available \n
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		return self._core.io.query_struct(f'SENSe:CORRection:TRANsducer:CATalog?', self.__class__.GetStruct())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CountCls:
	"""Count commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	def get(self, powerMeter=repcap.PowerMeter.Default) -> float:
		"""SCPI: SYSTem:COMMunicate:RDEVice:PMETer<p>:COUNt \n
		Snippet: value: float = driver.system.communicate.rdevice.pmeter.count.get(powerMeter = repcap.PowerMeter.Default) \n
		No command help available \n
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
			:return: number_sensors: No help available"""
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		response = self._core.io.query_str(f'SYSTem:COMMunicate:RDEVice:PMETer{powerMeter_cmd_val}:COUNt?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IdentifyCls:
	"""Identify commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("identify", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:CREFerence:HARMonics:IDENtify \n
		Snippet: driver.applications.k50Spurious.sense.creference.harmonics.identify.set(state = False) \n
		Enables or disables the identification of harmonics of the carrier. \n
			:param state: ON | 1 HArmonics are marked OFF | 0 Harmonics are not marked
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:CREFerence:HARMonics:IDENtify {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:CREFerence:HARMonics:IDENtify \n
		Snippet: value: bool = driver.applications.k50Spurious.sense.creference.harmonics.identify.get() \n
		Enables or disables the identification of harmonics of the carrier. \n
			:return: state: ON | 1 HArmonics are marked OFF | 0 Harmonics are not marked"""
		response = self._core.io.query_str(f'SENSe:CREFerence:HARMonics:IDENtify?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ListPyCls:
	"""ListPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("listPy", core, parent)

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Option: str: No parameter help available
			- State: enums.OptionState: No parameter help available
			- Days: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_str('Option'),
			ArgStruct.scalar_enum('State', enums.OptionState),
			ArgStruct.scalar_float('Days')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Option: str = None
			self.State: enums.OptionState = None
			self.Days: float = None

	def get(self) -> GetStruct:
		"""SCPI: SYSTem:OPTion:LICense[:LIST] \n
		Snippet: value: GetStruct = driver.system.option.license.listPy.get() \n
		No command help available \n
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		return self._core.io.query_struct(f'SYSTem:OPTion:LICense:LIST?', self.__class__.GetStruct())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SourceCls:
	"""Source commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	def set(self, source: enums.SourceInt) -> None:
		"""SCPI: SOURce:EXTernal:ROSCillator[:SOURce] \n
		Snippet: driver.applications.k30NoiseFigure.source.external.roscillator.source.set(source = enums.SourceInt.EXTernal) \n
		This command controls selection of the reference oscillator for the external generator. This command is only valid if
		External Generator Control (R&S FSWP-B10) is installed. If the external reference oscillator is selected, the reference
		signal must be connected to the rear panel of the instrument. \n
			:param source: INTernal Uses the internal reference. EXTernal Uses the external reference; if none is available, an error flag is displayed in the status bar.
		"""
		param = Conversions.enum_scalar_to_str(source, enums.SourceInt)
		self._core.io.write(f'SOURce:EXTernal:ROSCillator:SOURce {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SourceInt:
		"""SCPI: SOURce:EXTernal:ROSCillator[:SOURce] \n
		Snippet: value: enums.SourceInt = driver.applications.k30NoiseFigure.source.external.roscillator.source.get() \n
		This command controls selection of the reference oscillator for the external generator. This command is only valid if
		External Generator Control (R&S FSWP-B10) is installed. If the external reference oscillator is selected, the reference
		signal must be connected to the rear panel of the instrument. \n
			:return: source: INTernal Uses the internal reference. EXTernal Uses the external reference; if none is available, an error flag is displayed in the status bar."""
		response = self._core.io.query_str(f'SOURce:EXTernal:ROSCillator:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.SourceInt)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.RepeatedCapability import RepeatedCapability
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DefaultCls:
	"""Default commands group definition. 1 total commands, 0 Subgroups, 1 group commands
	Repeated Capability: Colors, default value after init: Colors.Ix1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("default", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_colors_get', 'repcap_colors_set', repcap.Colors.Ix1)

	def repcap_colors_set(self, colors: repcap.Colors) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Colors.Default
		Default value after init: Colors.Ix1"""
		self._cmd_group.set_repcap_enum_value(colors)

	def repcap_colors_get(self) -> repcap.Colors:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	def set(self, item=repcap.Item.Default, colors=repcap.Colors.Default) -> None:
		"""SCPI: DISPlay:CMAP<it>:DEFault<ci> \n
		Snippet: driver.display.cmap.default.set(item = repcap.Item.Default, colors = repcap.Colors.Default) \n
		This command selects the color scheme for the display. The query returns the default color scheme. \n
			:param item: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Cmap')
			:param colors: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Default')
		"""
		item_cmd_val = self._cmd_group.get_repcap_cmd_value(item, repcap.Item)
		colors_cmd_val = self._cmd_group.get_repcap_cmd_value(colors, repcap.Colors)
		self._core.io.write(f'DISPlay:CMAP{item_cmd_val}:DEFault{colors_cmd_val}')

	def set_with_opc(self, item=repcap.Item.Default, colors=repcap.Colors.Default, opc_timeout_ms: int = -1) -> None:
		item_cmd_val = self._cmd_group.get_repcap_cmd_value(item, repcap.Item)
		colors_cmd_val = self._cmd_group.get_repcap_cmd_value(colors, repcap.Colors)
		"""SCPI: DISPlay:CMAP<it>:DEFault<ci> \n
		Snippet: driver.display.cmap.default.set_with_opc(item = repcap.Item.Default, colors = repcap.Colors.Default) \n
		This command selects the color scheme for the display. The query returns the default color scheme. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param item: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Cmap')
			:param colors: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Default')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'DISPlay:CMAP{item_cmd_val}:DEFault{colors_cmd_val}', opc_timeout_ms)

	def clone(self) -> 'DefaultCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DefaultCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SpurCls:
	"""Spur commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("spur", core, parent)

	def set(self, spur: List[int] = None) -> None:
		"""SCPI: [SENSe]:TRANsfer:SPUR \n
		Snippet: driver.applications.k50Spurious.sense.transfer.spur.set(spur = [1, 2, 3]) \n
		No command help available \n
			:param spur: Comma-separated list of spur numbers (integers)
		"""
		param = ''
		if spur:
			param = Conversions.list_to_csv_str(spur)
		self._core.io.write(f'SENSe:TRANsfer:SPUR {param}'.strip())



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, factory: enums.Factory) -> None:
		"""SCPI: [SENSe]:DDEMod:FACTory[:VALue] \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.factory.value.set(factory = enums.Factory.ALL) \n
		This command restores the factory settings of standards or patterns for the VSA application. \n
			:param factory: ALL | STANdard | PATTern ALL Restores both standards and patterns.
		"""
		param = Conversions.enum_scalar_to_str(factory, enums.Factory)
		self._core.io.write(f'SENSe:DDEMod:FACTory:VALue {param}')



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LdriftCls:
	"""Ldrift commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ldrift", core, parent)

	def get(self, trace=repcap.Trace.Default) -> List[float]:
		"""SCPI: FETCh:PNOise<t>:SWEep:LDRift \n
		Snippet: value: List[float] = driver.applications.k40PhaseNoise.fetch.pnoise.sweep.ldrift.get(trace = repcap.Trace.Default) \n
		No command help available \n
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Pnoise')
			:return: level_drifts: No help available"""
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_bin_or_ascii_float_list(f'FETCh:PNOise{trace_cmd_val}:SWEep:LDRift?')
		return response



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IqPowerCls:
	"""IqPower commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("iqPower", core, parent)

	def set(self, level_iq_power: float, triggerPort=repcap.TriggerPort.Default) -> None:
		"""SCPI: TRIGger<tp>[:SEQuence]:LEVel:IQPower \n
		Snippet: driver.applications.k70Vsa.trigger.sequence.level.iqPower.set(level_iq_power = 1.0, triggerPort = repcap.TriggerPort.Default) \n
		This command defines the magnitude the I/Q data must exceed to cause a trigger event. Note that any RF attenuation or
		preamplification is considered when the trigger level is analyzed. If defined, a reference level offset is also
		considered. \n
			:param level_iq_power: Range: -130 dBm to 30 dBm, Unit: DBM
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
		"""
		param = Conversions.decimal_value_to_str(level_iq_power)
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		self._core.io.write(f'TRIGger{triggerPort_cmd_val}:SEQuence:LEVel:IQPower {param}')

	def get(self, triggerPort=repcap.TriggerPort.Default) -> float:
		"""SCPI: TRIGger<tp>[:SEQuence]:LEVel:IQPower \n
		Snippet: value: float = driver.applications.k70Vsa.trigger.sequence.level.iqPower.get(triggerPort = repcap.TriggerPort.Default) \n
		This command defines the magnitude the I/Q data must exceed to cause a trigger event. Note that any RF attenuation or
		preamplification is considered when the trigger level is analyzed. If defined, a reference level offset is also
		considered. \n
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
			:return: level_iq_power: No help available"""
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		response = self._core.io.query_str(f'TRIGger{triggerPort_cmd_val}:SEQuence:LEVel:IQPower?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SsearchCls:
	"""Ssearch commands group definition. 7 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ssearch", core, parent)

	@property
	def stype(self):
		"""stype commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_stype'):
			from .Stype import StypeCls
			self._stype = StypeCls(self._core, self._cmd_group)
		return self._stype

	@property
	def fplan(self):
		"""fplan commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_fplan'):
			from .Fplan import FplanCls
			self._fplan = FplanCls(self._core, self._cmd_group)
		return self._fplan

	@property
	def mspur(self):
		"""mspur commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mspur'):
			from .Mspur import MspurCls
			self._mspur = MspurCls(self._core, self._cmd_group)
		return self._mspur

	@property
	def rremove(self):
		"""rremove commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rremove'):
			from .Rremove import RremoveCls
			self._rremove = RremoveCls(self._core, self._cmd_group)
		return self._rremove

	@property
	def rmark(self):
		"""rmark commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rmark'):
			from .Rmark import RmarkCls
			self._rmark = RmarkCls(self._core, self._cmd_group)
		return self._rmark

	@property
	def control(self):
		"""control commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_control'):
			from .Control import ControlCls
			self._control = ControlCls(self._core, self._cmd_group)
		return self._control

	def clone(self) -> 'SsearchCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SsearchCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IfPowerCls:
	"""IfPower commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ifPower", core, parent)

	def set(self, level_if_power: float, triggerPort=repcap.TriggerPort.Default) -> None:
		"""SCPI: TRIGger<tp>[:SEQuence]:LEVel:IFPower \n
		Snippet: driver.applications.k70Vsa.trigger.sequence.level.ifPower.set(level_if_power = 1.0, triggerPort = repcap.TriggerPort.Default) \n
		This command defines the power level at the third intermediate frequency that must be exceeded to cause a trigger event.
		Note that any RF attenuation or preamplification is considered when the trigger level is analyzed.
		If defined, a reference level offset is also considered. \n
			:param level_if_power: For details on available trigger levels and trigger bandwidths, see the data sheet. Unit: DBM
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
		"""
		param = Conversions.decimal_value_to_str(level_if_power)
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		self._core.io.write(f'TRIGger{triggerPort_cmd_val}:SEQuence:LEVel:IFPower {param}')

	def get(self, triggerPort=repcap.TriggerPort.Default) -> float:
		"""SCPI: TRIGger<tp>[:SEQuence]:LEVel:IFPower \n
		Snippet: value: float = driver.applications.k70Vsa.trigger.sequence.level.ifPower.get(triggerPort = repcap.TriggerPort.Default) \n
		This command defines the power level at the third intermediate frequency that must be exceeded to cause a trigger event.
		Note that any RF attenuation or preamplification is considered when the trigger level is analyzed.
		If defined, a reference level offset is also considered. \n
			:param triggerPort: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trigger')
			:return: level_if_power: No help available"""
		triggerPort_cmd_val = self._cmd_group.get_repcap_cmd_value(triggerPort, repcap.TriggerPort)
		response = self._core.io.query_str(f'TRIGger{triggerPort_cmd_val}:SEQuence:LEVel:IFPower?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, limit_value: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit:MACCuracy:CFERror:MEAN:VALue \n
		Snippet: driver.applications.k70Vsa.calculate.limit.maccuracy.cfError.mean.value.set(limit_value = 1.0, window = repcap.Window.Default) \n
		This command defines the limit for the current, peak or mean center frequency error limit. Note that the limits for the
		current and the peak value are always kept identical. \n
			:param limit_value: the value x (x0) defines the interval [-x; x] Range: 0.0 to 1000000, Unit: Hz
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(limit_value)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit:MACCuracy:CFERror:MEAN:VALue {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:LIMit:MACCuracy:CFERror:MEAN:VALue \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.limit.maccuracy.cfError.mean.value.get(window = repcap.Window.Default) \n
		This command defines the limit for the current, peak or mean center frequency error limit. Note that the limits for the
		current and the peak value are always kept identical. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: limit_value: the value x (x0) defines the interval [-x; x] Range: 0.0 to 1000000, Unit: Hz"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit:MACCuracy:CFERror:MEAN:VALue?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FactorCls:
	"""Factor commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("factor", core, parent)

	@property
	def numerator(self):
		"""numerator commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_numerator'):
			from .Numerator import NumeratorCls
			self._numerator = NumeratorCls(self._core, self._cmd_group)
		return self._numerator

	@property
	def denominator(self):
		"""denominator commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_denominator'):
			from .Denominator import DenominatorCls
			self._denominator = DenominatorCls(self._core, self._cmd_group)
		return self._denominator

	def clone(self) -> 'FactorCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FactorCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LoCls:
	"""Lo commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("lo", core, parent)

	@property
	def frequency(self):
		"""frequency commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	def set(self, lo_type: enums.LoType) -> None:
		"""SCPI: [SENSe]:CONFigure:MODE:SYSTem:LO \n
		Snippet: driver.applications.k30NoiseFigure.sense.configure.mode.system.lo.set(lo_type = enums.LoType.FIXed) \n
		This command selects the type of local oscillator you are using. The command is available for measurements on frequency
		converting DUTs [SENSe:]CONFigure:MODE:DUT . \n
			:param lo_type: FIXed | VARiable FIXed The local oscillator is used as a fixed frequency source. The IF is variable. VARiable The local oscillator is used as a variable frequency source. The IF is fixed.
		"""
		param = Conversions.enum_scalar_to_str(lo_type, enums.LoType)
		self._core.io.write(f'SENSe:CONFigure:MODE:SYSTem:LO {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.LoType:
		"""SCPI: [SENSe]:CONFigure:MODE:SYSTem:LO \n
		Snippet: value: enums.LoType = driver.applications.k30NoiseFigure.sense.configure.mode.system.lo.get() \n
		This command selects the type of local oscillator you are using. The command is available for measurements on frequency
		converting DUTs [SENSe:]CONFigure:MODE:DUT . \n
			:return: lo_type: FIXed | VARiable FIXed The local oscillator is used as a fixed frequency source. The IF is variable. VARiable The local oscillator is used as a variable frequency source. The IF is fixed."""
		response = self._core.io.query_str(f'SENSe:CONFigure:MODE:SYSTem:LO?')
		return Conversions.str_to_scalar_enum(response, enums.LoType)

	def clone(self) -> 'LoCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LoCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ItemCls:
	"""Item commands group definition. 18 total commands, 16 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("item", core, parent)

	@property
	def default(self):
		"""default commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_default'):
			from .Default import DefaultCls
			self._default = DefaultCls(self._core, self._cmd_group)
		return self._default

	@property
	def nonePy(self):
		"""nonePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nonePy'):
			from .NonePy import NonePyCls
			self._nonePy = NonePyCls(self._core, self._cmd_group)
		return self._nonePy

	@property
	def hwSettings(self):
		"""hwSettings commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hwSettings'):
			from .HwSettings import HwSettingsCls
			self._hwSettings = HwSettingsCls(self._core, self._cmd_group)
		return self._hwSettings

	@property
	def trace(self):
		"""trace commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_trace'):
			from .Trace import TraceCls
			self._trace = TraceCls(self._core, self._cmd_group)
		return self._trace

	@property
	def lines(self):
		"""lines commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_lines'):
			from .Lines import LinesCls
			self._lines = LinesCls(self._core, self._cmd_group)
		return self._lines

	@property
	def csetup(self):
		"""csetup commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_csetup'):
			from .Csetup import CsetupCls
			self._csetup = CsetupCls(self._core, self._cmd_group)
		return self._csetup

	@property
	def cdata(self):
		"""cdata commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cdata'):
			from .Cdata import CdataCls
			self._cdata = CdataCls(self._core, self._cmd_group)
		return self._cdata

	@property
	def hardCopy(self):
		"""hardCopy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hardCopy'):
			from .HardCopy import HardCopyCls
			self._hardCopy = HardCopyCls(self._core, self._cmd_group)
		return self._hardCopy

	@property
	def macros(self):
		"""macros commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_macros'):
			from .Macros import MacrosCls
			self._macros = MacrosCls(self._core, self._cmd_group)
		return self._macros

	@property
	def scData(self):
		"""scData commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scData'):
			from .ScData import ScDataCls
			self._scData = ScDataCls(self._core, self._cmd_group)
		return self._scData

	@property
	def transducer(self):
		"""transducer commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_transducer'):
			from .Transducer import TransducerCls
			self._transducer = TransducerCls(self._core, self._cmd_group)
		return self._transducer

	@property
	def spectrogram(self):
		"""spectrogram commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_spectrogram'):
			from .Spectrogram import SpectrogramCls
			self._spectrogram = SpectrogramCls(self._core, self._cmd_group)
		return self._spectrogram

	@property
	def final(self):
		"""final commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_final'):
			from .Final import FinalCls
			self._final = FinalCls(self._core, self._cmd_group)
		return self._final

	@property
	def viqData(self):
		"""viqData commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_viqData'):
			from .ViqData import ViqDataCls
			self._viqData = ViqDataCls(self._core, self._cmd_group)
		return self._viqData

	@property
	def all(self):
		"""all commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	@property
	def weighting(self):
		"""weighting commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_weighting'):
			from .Weighting import WeightingCls
			self._weighting = WeightingCls(self._core, self._cmd_group)
		return self._weighting

	def clone(self) -> 'ItemCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ItemCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.AutoManualMode) -> None:
		"""SCPI: [SENSe]:ROSCillator:COUPling:BANDwidth:MODE \n
		Snippet: driver.sense.roscillator.coupling.bandwidth.mode.set(mode = enums.AutoManualMode.AUTO) \n
		This command selects coupling bandwidth mode for the internal reference frequency.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Options R&S FSWP-B60 or -B61 must be available. \n
			:param mode: AUTO Automatically selects an appropriate coupling bandwidth. MANual Manual selection of coupling bandwidth. You can select the bandwidth with [SENSe:]ROSCillator:COUPling:BANDwidth.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.AutoManualMode)
		self._core.io.write(f'SENSe:ROSCillator:COUPling:BANDwidth:MODE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.AutoManualMode:
		"""SCPI: [SENSe]:ROSCillator:COUPling:BANDwidth:MODE \n
		Snippet: value: enums.AutoManualMode = driver.sense.roscillator.coupling.bandwidth.mode.get() \n
		This command selects coupling bandwidth mode for the internal reference frequency.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Options R&S FSWP-B60 or -B61 must be available. \n
			:return: mode: AUTO Automatically selects an appropriate coupling bandwidth. MANual Manual selection of coupling bandwidth. You can select the bandwidth with [SENSe:]ROSCillator:COUPling:BANDwidth."""
		response = self._core.io.query_str(f'SENSe:ROSCillator:COUPling:BANDwidth:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.AutoManualMode)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SystemCls:
	"""System commands group definition. 11 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("system", core, parent)

	@property
	def communicate(self):
		"""communicate commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_communicate'):
			from .Communicate import CommunicateCls
			self._communicate = CommunicateCls(self._core, self._cmd_group)
		return self._communicate

	@property
	def configure(self):
		"""configure commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_configure'):
			from .Configure import ConfigureCls
			self._configure = ConfigureCls(self._core, self._cmd_group)
		return self._configure

	def clone(self) -> 'SystemCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SystemCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LevelCls:
	"""Level commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("level", core, parent)

	def set(self, threshold: float) -> None:
		"""SCPI: [SENSe]:ADEMod:SQUelch:LEVel \n
		Snippet: driver.sense.ademod.squelch.level.set(threshold = 1.0) \n
		This command defines the level threshold below which the demodulated data is set to 0 if squelching is enabled (see
		[SENSe:]ADEMod:SQUelch[:STATe]) . \n
			:param threshold: numeric value The absolute threshold level Range: -150 dBm to 30 dBm
		"""
		param = Conversions.decimal_value_to_str(threshold)
		self._core.io.write(f'SENSe:ADEMod:SQUelch:LEVel {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:ADEMod:SQUelch:LEVel \n
		Snippet: value: float = driver.sense.ademod.squelch.level.get() \n
		This command defines the level threshold below which the demodulated data is set to 0 if squelching is enabled (see
		[SENSe:]ADEMod:SQUelch[:STATe]) . \n
			:return: threshold: numeric value The absolute threshold level Range: -150 dBm to 30 dBm"""
		response = self._core.io.query_str(f'SENSe:ADEMod:SQUelch:LEVel?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, gain: float) -> None:
		"""SCPI: INPut:GAIN[:VALue] \n
		Snippet: driver.applications.k60Transient.inputPy.gain.value.set(gain = 1.0) \n
		This command selects the 'gain' if the preamplifier is activated (INP:GAIN:STAT ON, see method RsFswp.Applications.
		K30_NoiseFigure.InputPy.Gain.State.set) . The command requires the additional preamplifier hardware option. \n
			:param gain: For R&S FSWP models 1322.8003K08, 1322.8003K09, 1322.8003K27 and 1322.8003K51, the following settings are available: 15 dB and 30 dB All other values are rounded to the nearest of these two. For R&S FSWP models 1322.8003K26 and 1322.8003K50: 30 dB Unit: DB
		"""
		param = Conversions.decimal_value_to_str(gain)
		self._core.io.write(f'INPut:GAIN:VALue {param}')

	def get(self) -> float:
		"""SCPI: INPut:GAIN[:VALue] \n
		Snippet: value: float = driver.applications.k60Transient.inputPy.gain.value.get() \n
		This command selects the 'gain' if the preamplifier is activated (INP:GAIN:STAT ON, see method RsFswp.Applications.
		K30_NoiseFigure.InputPy.Gain.State.set) . The command requires the additional preamplifier hardware option. \n
			:return: gain: For R&S FSWP models 1322.8003K08, 1322.8003K09, 1322.8003K27 and 1322.8003K51, the following settings are available: 15 dB and 30 dB All other values are rounded to the nearest of these two. For R&S FSWP models 1322.8003K26 and 1322.8003K50: 30 dB Unit: DB"""
		response = self._core.io.query_str(f'INPut:GAIN:VALue?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Utilities import trim_str_response
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EventCls:
	"""Event commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("event", core, parent)

	def get(self, window=repcap.Window.Default) -> str:
		"""SCPI: STATus:QUEStionable:MODulation<Window>[:EVENt] \n
		Snippet: value: str = driver.applications.k70Vsa.status.questionable.modulation.event.get(window = repcap.Window.Default) \n
		This command reads out the EVENt section of the status register. The command also deletes the contents of the EVENt
		section. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Modulation')
			:return: channel_name: String containing the name of the channel. The parameter is optional. If you omit it, the command works for the currently active channel."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'STATus:QUEStionable:MODulation{window_cmd_val}:EVENt?')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: DISPlay:SBAR[:STATe] \n
		Snippet: driver.display.sbar.state.set(state = False) \n
		This command turns the status bar on and off. \n
			:param state: ON | OFF | 0 | 1
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'DISPlay:SBAR:STATe {param}')

	def get(self) -> bool:
		"""SCPI: DISPlay:SBAR[:STATe] \n
		Snippet: value: bool = driver.display.sbar.state.get() \n
		This command turns the status bar on and off. \n
			:return: state: ON | OFF | 0 | 1"""
		response = self._core.io.query_str(f'DISPlay:SBAR:STATe?')
		return Conversions.str_to_bool(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, use_wfm_for_sync: enums.AutoManualMode) -> None:
		"""SCPI: [SENSe]:DDEMod:SEARch:PATTern:SYNC:AUTO \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.search.pattern.sync.auto.set(use_wfm_for_sync = enums.AutoManualMode.AUTO) \n
		This command selects manual or automatic synchronization with a pattern waveform to speed up measurements. \n
			:param use_wfm_for_sync: AUTO | MANual
		"""
		param = Conversions.enum_scalar_to_str(use_wfm_for_sync, enums.AutoManualMode)
		self._core.io.write(f'SENSe:DDEMod:SEARch:PATTern:SYNC:AUTO {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.AutoManualMode:
		"""SCPI: [SENSe]:DDEMod:SEARch:PATTern:SYNC:AUTO \n
		Snippet: value: enums.AutoManualMode = driver.applications.k70Vsa.sense.ddemod.search.pattern.sync.auto.get() \n
		This command selects manual or automatic synchronization with a pattern waveform to speed up measurements. \n
			:return: use_wfm_for_sync: AUTO | MANual"""
		response = self._core.io.query_str(f'SENSe:DDEMod:SEARch:PATTern:SYNC:AUTO?')
		return Conversions.str_to_scalar_enum(response, enums.AutoManualMode)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BiasCls:
	"""Bias commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bias", core, parent)

	def set(self, bias: float) -> None:
		"""SCPI: [SENSe]:CORRection:CVL:BIAS \n
		Snippet: driver.applications.k50Spurious.sense.correction.cvl.bias.set(bias = 1.0) \n
		This command defines the bias setting to be used with the conversion loss table. Before this command can be performed,
		the conversion loss table must be selected (see [SENSe:]CORRection:CVL:SELect. This command is only available with option
		B21 (External Mixer) installed. \n
			:param bias: Unit: A
		"""
		param = Conversions.decimal_value_to_str(bias)
		self._core.io.write(f'SENSe:CORRection:CVL:BIAS {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:CORRection:CVL:BIAS \n
		Snippet: value: float = driver.applications.k50Spurious.sense.correction.cvl.bias.get() \n
		This command defines the bias setting to be used with the conversion loss table. Before this command can be performed,
		the conversion loss table must be selected (see [SENSe:]CORRection:CVL:SELect. This command is only available with option
		B21 (External Mixer) installed. \n
			:return: bias: No help available"""
		response = self._core.io.query_str(f'SENSe:CORRection:CVL:BIAS?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PortsCls:
	"""Ports commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ports", core, parent)

	def set(self, port_type: int) -> None:
		"""SCPI: [SENSe]:CORRection:CVL:PORTs \n
		Snippet: driver.applications.k60Transient.sense.correction.cvl.ports.set(port_type = 1) \n
		No command help available \n
			:param port_type: No help available
		"""
		param = Conversions.decimal_value_to_str(port_type)
		self._core.io.write(f'SENSe:CORRection:CVL:PORTs {param}')

	def get(self, port_type: int) -> int:
		"""SCPI: [SENSe]:CORRection:CVL:PORTs \n
		Snippet: value: int = driver.applications.k60Transient.sense.correction.cvl.ports.get(port_type = 1) \n
		No command help available \n
			:param port_type: No help available
			:return: port_type: No help available"""
		param = Conversions.decimal_value_to_str(port_type)
		response = self._core.io.query_str(f'SENSe:CORRection:CVL:PORTs? {param}')
		return Conversions.str_to_int(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BandwidthCls:
	"""Bandwidth commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bandwidth", core, parent)

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	def set(self, bandwidth: float) -> None:
		"""SCPI: [SENSe]:ROSCillator:COUPling:BANDwidth \n
		Snippet: driver.sense.roscillator.coupling.bandwidth.set(bandwidth = 1.0) \n
		This command defines coupling bandwidth for the internal reference frequency.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Options R&S FSWP-B60 or -B61 must be available.
			- Select manual bandwidth mode ([SENSe:]ROSCillator:COUPling:BANDwidth:MODE)  \n
			:param bandwidth: numeric value Bandwidths 20 mHz, 1 Hz and 100 kHz are supported. Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(bandwidth)
		self._core.io.write(f'SENSe:ROSCillator:COUPling:BANDwidth {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:ROSCillator:COUPling:BANDwidth \n
		Snippet: value: float = driver.sense.roscillator.coupling.bandwidth.get() \n
		This command defines coupling bandwidth for the internal reference frequency.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Options R&S FSWP-B60 or -B61 must be available.
			- Select manual bandwidth mode ([SENSe:]ROSCillator:COUPling:BANDwidth:MODE)  \n
			:return: bandwidth: numeric value Bandwidths 20 mHz, 1 Hz and 100 kHz are supported. Unit: Hz"""
		response = self._core.io.query_str(f'SENSe:ROSCillator:COUPling:BANDwidth?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'BandwidthCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = BandwidthCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, arg_0: enums.EventOnce, window=repcap.Window.Default, powerMeter=repcap.PowerMeter.Default) -> None:
		"""SCPI: CALCulate<n>:PMETer<p>:RELative[:MAGNitude]:AUTO \n
		Snippet: driver.applications.k50Spurious.calculate.pmeter.relative.magnitude.auto.set(arg_0 = enums.EventOnce.ONCE, window = repcap.Window.Default, powerMeter = repcap.PowerMeter.Default) \n
		This command sets the current measurement result as the reference level for relative measurements. \n
			:param arg_0: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
		"""
		param = Conversions.enum_scalar_to_str(arg_0, enums.EventOnce)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		self._core.io.write(f'CALCulate{window_cmd_val}:PMETer{powerMeter_cmd_val}:RELative:MAGNitude:AUTO {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Types import DataType
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PortCls:
	"""Port commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("port", core, parent)

	def set(self, dev_name: str, port: enums.TriggerPort) -> None:
		"""SCPI: TRIGger:SENDer:PORT \n
		Snippet: driver.trigger.sender.port.set(dev_name = '1', port = enums.TriggerPort.EXT1) \n
		No command help available \n
			:param dev_name: No help available
			:param port: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('dev_name', dev_name, DataType.String), ArgSingle('port', port, DataType.Enum, enums.TriggerPort))
		self._core.io.write(f'TRIGger:SENDer:PORT {param}'.rstrip())

	# noinspection PyTypeChecker
	def get(self) -> enums.TriggerPort:
		"""SCPI: TRIGger:SENDer:PORT \n
		Snippet: value: enums.TriggerPort = driver.trigger.sender.port.get() \n
		No command help available \n
			:return: port: No help available"""
		response = self._core.io.query_str(f'TRIGger:SENDer:PORT?')
		return Conversions.str_to_scalar_enum(response, enums.TriggerPort)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPyCls:
	"""FormatPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("formatPy", core, parent)

	def set(self, format_py: enums.HumsFileFormat) -> None:
		"""SCPI: DIAGnostic:HUMS:FORMat \n
		Snippet: driver.diagnostic.hums.formatPy.set(format_py = enums.HumsFileFormat.JSON) \n
		Selects the format for the queried HUMS data. You can query the HUMS data either in JSON format or XML format.
		The defined format affects all other commands that return block data. \n
			:param format_py: JSON | XML JSON Returns the HUMS data in JSON format. XML Returns the HUMS data in XML format.
		"""
		param = Conversions.enum_scalar_to_str(format_py, enums.HumsFileFormat)
		self._core.io.write(f'DIAGnostic:HUMS:FORMat {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.HumsFileFormat:
		"""SCPI: DIAGnostic:HUMS:FORMat \n
		Snippet: value: enums.HumsFileFormat = driver.diagnostic.hums.formatPy.get() \n
		Selects the format for the queried HUMS data. You can query the HUMS data either in JSON format or XML format.
		The defined format affects all other commands that return block data. \n
			:return: format_py: No help available"""
		response = self._core.io.query_str(f'DIAGnostic:HUMS:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.HumsFileFormat)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SymbolRateCls:
	"""SymbolRate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("symbolRate", core, parent)

	def set(self, count: int) -> None:
		"""SCPI: TRACe:IQ:SRATe \n
		Snippet: driver.applications.iqAnalyzer.trace.iq.symbolRate.set(count = 1) \n
		This command sets the final user sample rate for the acquired I/Q data. Thus, the user sample rate can be modified
		without affecting the actual data capturing settings on the R&S FSWP. Note: The smaller the user sample rate, the smaller
		the usable I/Q bandwidth, see 'Sample rate and maximum usable I/Q bandwidth for RF input'. \n
			:param count: The valid sample rates are described in 'Sample rate and maximum usable I/Q bandwidth for RF input'. Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(count)
		self._core.io.write(f'TRACe:IQ:SRATe {param}')

	def get(self) -> int:
		"""SCPI: TRACe:IQ:SRATe \n
		Snippet: value: int = driver.applications.iqAnalyzer.trace.iq.symbolRate.get() \n
		This command sets the final user sample rate for the acquired I/Q data. Thus, the user sample rate can be modified
		without affecting the actual data capturing settings on the R&S FSWP. Note: The smaller the user sample rate, the smaller
		the usable I/Q bandwidth, see 'Sample rate and maximum usable I/Q bandwidth for RF input'. \n
			:return: count: No help available"""
		response = self._core.io.query_str(f'TRACe:IQ:SRATe?')
		return Conversions.str_to_int(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IqImbalanceCls:
	"""IqImbalance commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("iqImbalance", core, parent)

	def get(self, result_type: enums.ResultTypeStat, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:DDEMod:STATistic:IQIMbalance \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.marker.function.ddemod.statistic.iqImbalance.get(result_type = enums.ResultTypeStat.AVG, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command queries the results of the I/Q imbalance error measurement of digital demodulation. \n
			:param result_type: none I/Q imbalance error (for current sweep) AVG Average I/Q imbalance error over several sweeps RPE Peak I/Q imbalance error over several sweeps SDEV Standard deviation of I/Q imbalance error PCTL 95 percentile value of I/Q imbalance error
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: result: No help available"""
		param = Conversions.enum_scalar_to_str(result_type, enums.ResultTypeStat)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:DDEMod:STATistic:IQIMbalance? {param}')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TraceCls:
	"""Trace commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("trace", core, parent)

	def set(self, trace: float, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default) -> None:
		"""SCPI: CALCulate<n>:DELTamarker<m>:TRACe \n
		Snippet: driver.applications.k30NoiseFigure.calculate.deltaMarker.trace.set(trace = 1.0, window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		This command selects the trace a delta marker is positioned on. Note that the corresponding trace must have a trace mode
		other than 'Blank'. If necessary, the command activates the marker first. \n
			:param trace: Trace number the marker is assigned to.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
		"""
		param = Conversions.decimal_value_to_str(trace)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		self._core.io.write(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:TRACe {param}')

	def get(self, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default) -> float:
		"""SCPI: CALCulate<n>:DELTamarker<m>:TRACe \n
		Snippet: value: float = driver.applications.k30NoiseFigure.calculate.deltaMarker.trace.get(window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		This command selects the trace a delta marker is positioned on. Note that the corresponding trace must have a trace mode
		other than 'Blank'. If necessary, the command activates the marker first. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
			:return: trace: Trace number the marker is assigned to."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:TRACe?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SpotCls:
	"""Spot commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("spot", core, parent)

	def set(self, loss: float) -> None:
		"""SCPI: [SENSe]:CORRection:LOSS:CALibration:SPOT \n
		Snippet: driver.applications.k30NoiseFigure.sense.correction.loss.calibration.spot.set(loss = 1.0) \n
		This command defines a constant calibration loss for all measurement points. \n
			:param loss: Range: -999.99 to 999.99, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(loss)
		self._core.io.write(f'SENSe:CORRection:LOSS:CALibration:SPOT {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:CORRection:LOSS:CALibration:SPOT \n
		Snippet: value: float = driver.applications.k30NoiseFigure.sense.correction.loss.calibration.spot.get() \n
		This command defines a constant calibration loss for all measurement points. \n
			:return: loss: Range: -999.99 to 999.99, Unit: dB"""
		response = self._core.io.query_str(f'SENSe:CORRection:LOSS:CALibration:SPOT?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PrateCls:
	"""Prate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("prate", core, parent)

	def set(self, capt_oversampling: float) -> None:
		"""SCPI: [SENSe]:DDEMod:PRATe \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.prate.set(capt_oversampling = 1.0) \n
		Defines the number of samples that are captured per symbol, i.e. the factor by which the symbol rate is multiplied to
		obtain the sample rate. This parameter also affects the demodulation bandwidth and thus the usable I/Q bandwidth.
		The sample rate depends on the defined 'Symbol Rate' (see 'Sample rate, symbol rate and I/Q bandwidth') . \n
			:param capt_oversampling: | 2 | 4 | 8 | 16 | 32 | 64 | 128 The factor by which the symbol rate is multiplied to obtain the sample rate, e.g. 4 samples per symbol: sample rate = 4*symbol rate
		"""
		param = Conversions.decimal_value_to_str(capt_oversampling)
		self._core.io.write(f'SENSe:DDEMod:PRATe {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DDEMod:PRATe \n
		Snippet: value: float = driver.applications.k70Vsa.sense.ddemod.prate.get() \n
		Defines the number of samples that are captured per symbol, i.e. the factor by which the symbol rate is multiplied to
		obtain the sample rate. This parameter also affects the demodulation bandwidth and thus the usable I/Q bandwidth.
		The sample rate depends on the defined 'Symbol Rate' (see 'Sample rate, symbol rate and I/Q bandwidth') . \n
			:return: capt_oversampling: | 2 | 4 | 8 | 16 | 32 | 64 | 128 The factor by which the symbol rate is multiplied to obtain the sample rate, e.g. 4 samples per symbol: sample rate = 4*symbol rate"""
		response = self._core.io.query_str(f'SENSe:DDEMod:PRATe?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, trace=repcap.Trace.Default) -> None:
		"""SCPI: CONFigure:ADEMod:RESults:AM:DETector<det>:STATe \n
		Snippet: driver.configure.ademod.results.am.detector.state.set(state = False, trace = repcap.Trace.Default) \n
		Activates relative demodulation for the selected detector. If activated, the demodulated result is set in relation to the
		reference value defined by method RsFswp.Configure.Ademod.Results.Pm.Detector.Reference.set. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Detector')
		"""
		param = Conversions.bool_to_str(state)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'CONFigure:ADEMod:RESults:AM:DETector{trace_cmd_val}:STATe {param}')

	def get(self, trace=repcap.Trace.Default) -> bool:
		"""SCPI: CONFigure:ADEMod:RESults:AM:DETector<det>:STATe \n
		Snippet: value: bool = driver.configure.ademod.results.am.detector.state.get(trace = repcap.Trace.Default) \n
		Activates relative demodulation for the selected detector. If activated, the demodulated result is set in relation to the
		reference value defined by method RsFswp.Configure.Ademod.Results.Pm.Detector.Reference.set. \n
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Detector')
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'CONFigure:ADEMod:RESults:AM:DETector{trace_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RintervalCls:
	"""Rinterval commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rinterval", core, parent)

	def set(self, interval: float) -> None:
		"""SCPI: TRIGger[:SEQuence]:TIME:RINTerval \n
		Snippet: driver.trigger.sequence.time.rinterval.set(interval = 1.0) \n
		This command defines the repetition interval for the time trigger. \n
			:param interval: numeric value Range: 2 ms to 5000 s, Unit: S
		"""
		param = Conversions.decimal_value_to_str(interval)
		self._core.io.write(f'TRIGger:SEQuence:TIME:RINTerval {param}')

	def get(self) -> float:
		"""SCPI: TRIGger[:SEQuence]:TIME:RINTerval \n
		Snippet: value: float = driver.trigger.sequence.time.rinterval.get() \n
		This command defines the repetition interval for the time trigger. \n
			:return: interval: numeric value Range: 2 ms to 5000 s, Unit: S"""
		response = self._core.io.query_str(f'TRIGger:SEQuence:TIME:RINTerval?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MpowerCls:
	"""Mpower commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mpower", core, parent)

	def get(self, result_type: enums.ResultTypeStat, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:DDEMod:STATistic:MPOWer \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.marker.function.ddemod.statistic.mpower.get(result_type = enums.ResultTypeStat.AVG, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command queries the results of the power measurement of digital demodulation. \n
			:param result_type: none power measurement (for current sweep) AVG Average of power measurement over several sweeps RPE Peak of power measurement over several sweeps SDEV Standard deviation of power measurement PCTL 95 percentile value of power measurement
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: result: No help available"""
		param = Conversions.enum_scalar_to_str(result_type, enums.ResultTypeStat)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:DDEMod:STATistic:MPOWer? {param}')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IdentifyCls:
	"""Identify commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("identify", core, parent)

	@property
	def string(self):
		"""string commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_string'):
			from .String import StringCls
			self._string = StringCls(self._core, self._cmd_group)
		return self._string

	@property
	def factory(self):
		"""factory commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_factory'):
			from .Factory import FactoryCls
			self._factory = FactoryCls(self._core, self._cmd_group)
		return self._factory

	def clone(self) -> 'IdentifyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = IdentifyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SourceCls:
	"""Source commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	@property
	def eauto(self):
		"""eauto commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_eauto'):
			from .Eauto import EautoCls
			self._eauto = EautoCls(self._core, self._cmd_group)
		return self._eauto

	def set(self, source: enums.ReferenceSourceA) -> None:
		"""SCPI: [SENSe]:ROSCillator:SOURce \n
		Snippet: driver.sense.roscillator.source.set(source = enums.ReferenceSourceA.E10) \n
		This command selects the reference oscillator. If you want to select the external reference, it must be connected to the
		R&S FSWP. \n
			:param source: INTernal The internal reference is used (10 MHz) . EXTernal | EXTernal1 | EXT1 The external reference from the 'REF INPUT 10 MHZ' connector is used; if none is available, an error flag is displayed in the status bar. E10 The external reference from 'REF INPUT 1..50 MHZ' connector is used with a fixed 10 MHZ frequency; if none is available, an error flag is displayed in the status bar. E100 The external reference from the 'REF INPUT 100 MHZ / 1 GHz' connector is used with a fixed 100 MHZ frequency; if none is available, an error flag is displayed in the status bar. E1000 The external reference from 'REF INPUT 100 MHZ / 1 GHz' connector is used with a fixed 1 GHZ frequency; if none is available, an error flag is displayed in the status bar. EAUTo The external reference is used as long as it is available, then the instrument switches to the internal reference. SYNC The external reference is used; if none is available, an error flag is displayed in the status bar.
		"""
		param = Conversions.enum_scalar_to_str(source, enums.ReferenceSourceA)
		self._core.io.write(f'SENSe:ROSCillator:SOURce {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.ReferenceSourceA:
		"""SCPI: [SENSe]:ROSCillator:SOURce \n
		Snippet: value: enums.ReferenceSourceA = driver.sense.roscillator.source.get() \n
		This command selects the reference oscillator. If you want to select the external reference, it must be connected to the
		R&S FSWP. \n
			:return: source: INTernal The internal reference is used (10 MHz) . EXTernal | EXTernal1 | EXT1 The external reference from the 'REF INPUT 10 MHZ' connector is used; if none is available, an error flag is displayed in the status bar. E10 The external reference from 'REF INPUT 1..50 MHZ' connector is used with a fixed 10 MHZ frequency; if none is available, an error flag is displayed in the status bar. E100 The external reference from the 'REF INPUT 100 MHZ / 1 GHz' connector is used with a fixed 100 MHZ frequency; if none is available, an error flag is displayed in the status bar. E1000 The external reference from 'REF INPUT 100 MHZ / 1 GHz' connector is used with a fixed 1 GHZ frequency; if none is available, an error flag is displayed in the status bar. EAUTo The external reference is used as long as it is available, then the instrument switches to the internal reference. SYNC The external reference is used; if none is available, an error flag is displayed in the status bar."""
		response = self._core.io.query_str(f'SENSe:ROSCillator:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.ReferenceSourceA)

	def clone(self) -> 'SourceCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SourceCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StepCls:
	"""Step commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("step", core, parent)

	def set(self, stepsize: float) -> None:
		"""SCPI: [SENSe]:FREQuency:STEP \n
		Snippet: driver.applications.k30NoiseFigure.sense.frequency.step.set(stepsize = 1.0) \n
		This command defines the frequency stepsize in the frequency table. The stepsize corresponds to the distance from one
		measurement point to another. If you change the stepsize, the application creates a new frequency list. \n
			:param stepsize: Range: 0 Hz to span, Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(stepsize)
		self._core.io.write(f'SENSe:FREQuency:STEP {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:FREQuency:STEP \n
		Snippet: value: float = driver.applications.k30NoiseFigure.sense.frequency.step.get() \n
		This command defines the frequency stepsize in the frequency table. The stepsize corresponds to the distance from one
		measurement point to another. If you change the stepsize, the application creates a new frequency list. \n
			:return: stepsize: Range: 0 Hz to span, Unit: HZ"""
		response = self._core.io.query_str(f'SENSe:FREQuency:STEP?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)

	def get(self, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default) -> float:
		"""SCPI: CALCulate<n>:DELTamarker<m>:FUNCtion:AFPHase:RESult \n
		Snippet: value: float = driver.calculate.deltaMarker.function.afPhase.result.get(window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
			:return: af_phase: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:FUNCtion:AFPHase:RESult?')
		return Conversions.str_to_float(response)



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	def set(self, freq: List[int], level: List[int]) -> None:
		"""SCPI: [SENSe]:CORRection:CVL:DATA \n
		Snippet: driver.applications.k60Transient.sense.correction.cvl.data.set(freq = [1, 2, 3], level = [1, 2, 3]) \n
		No command help available \n
			:param freq: No help available
			:param level: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('freq', freq, DataType.IntegerList, None), ArgSingle.as_open_list('level', level, DataType.IntegerList, None))
		self._core.io.write(f'SENSe:CORRection:CVL:DATA {param}'.rstrip())

	def get(self, freq: List[int], level: List[int]) -> List[int]:
		"""SCPI: [SENSe]:CORRection:CVL:DATA \n
		Snippet: value: List[int] = driver.applications.k60Transient.sense.correction.cvl.data.get(freq = [1, 2, 3], level = [1, 2, 3]) \n
		No command help available \n
			:param freq: No help available
			:param level: No help available
			:return: freq: No help available"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('freq', freq, DataType.IntegerList, None), ArgSingle.as_open_list('level', level, DataType.IntegerList, None))
		response = self._core.io.query_bin_or_ascii_int_list(f'SENSe:CORRection:CVL:DATA? {param}'.rstrip())
		return response



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelfCls:
	"""Self commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("self", core, parent)

	@property
	def address(self):
		"""address commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_address'):
			from .Address import AddressCls
			self._address = AddressCls(self._core, self._cmd_group)
		return self._address

	@property
	def rterminator(self):
		"""rterminator commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rterminator'):
			from .Rterminator import RterminatorCls
			self._rterminator = RterminatorCls(self._core, self._cmd_group)
		return self._rterminator

	def clone(self) -> 'SelfCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SelfCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NetworkCls:
	"""Network commands group definition. 4 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("network", core, parent)

	@property
	def unusedDrives(self):
		"""unusedDrives commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_unusedDrives'):
			from .UnusedDrives import UnusedDrivesCls
			self._unusedDrives = UnusedDrivesCls(self._core, self._cmd_group)
		return self._unusedDrives

	@property
	def map(self):
		"""map commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_map'):
			from .Map import MapCls
			self._map = MapCls(self._core, self._cmd_group)
		return self._map

	@property
	def disconnect(self):
		"""disconnect commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_disconnect'):
			from .Disconnect import DisconnectCls
			self._disconnect = DisconnectCls(self._core, self._cmd_group)
		return self._disconnect

	@property
	def usedDrives(self):
		"""usedDrives commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_usedDrives'):
			from .UsedDrives import UsedDrivesCls
			self._usedDrives = UsedDrivesCls(self._core, self._cmd_group)
		return self._usedDrives

	def clone(self) -> 'NetworkCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = NetworkCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, theme: str) -> None:
		"""SCPI: DISPlay:THEMe:SELect \n
		Snippet: driver.display.theme.select.set(theme = '1') \n
		This command selects the display theme. \n
			:param theme: String containing the name of the theme.
		"""
		param = Conversions.value_to_quoted_str(theme)
		self._core.io.write(f'DISPlay:THEMe:SELect {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RestoreCls:
	"""Restore commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("restore", core, parent)

	def set(self, subBlock=repcap.SubBlock.Default) -> None:
		"""SCPI: [SENSe]:ESPectrum<sb>:PRESet:RESTore \n
		Snippet: driver.sense.espectrum.preset.restore.set(subBlock = repcap.SubBlock.Default) \n
		No command help available \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
		"""
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		self._core.io.write(f'SENSe:ESPectrum{subBlock_cmd_val}:PRESet:RESTore')

	def set_with_opc(self, subBlock=repcap.SubBlock.Default, opc_timeout_ms: int = -1) -> None:
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		"""SCPI: [SENSe]:ESPectrum<sb>:PRESet:RESTore \n
		Snippet: driver.sense.espectrum.preset.restore.set_with_opc(subBlock = repcap.SubBlock.Default) \n
		No command help available \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:ESPectrum{subBlock_cmd_val}:PRESet:RESTore', opc_timeout_ms)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DirectoryCls:
	"""Directory commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("directory", core, parent)

	def set(self, working_dir: str) -> None:
		"""SCPI: SYSTem:PLUGin:APPStarter:DIRectory \n
		Snippet: driver.system.plugin.appStarter.directory.set(working_dir = '1') \n
		No command help available \n
			:param working_dir: No help available
		"""
		param = Conversions.value_to_quoted_str(working_dir)
		self._core.io.write(f'SYSTem:PLUGin:APPStarter:DIRectory {param}')

	def get(self) -> str:
		"""SCPI: SYSTem:PLUGin:APPStarter:DIRectory \n
		Snippet: value: str = driver.system.plugin.appStarter.directory.get() \n
		No command help available \n
			:return: working_dir: No help available"""
		response = self._core.io.query_str(f'SYSTem:PLUGin:APPStarter:DIRectory?')
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, type_py: enums.EgateType) -> None:
		"""SCPI: [SENSe]:SWEep:EGATe:TYPE \n
		Snippet: driver.sense.sweep.egate.typePy.set(type_py = enums.EgateType.EDGE) \n
		This command selects the gate type.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Optional pulsed phase noise measurement application. \n
			:param type_py: EDGE The gate opens when the gate level has been exceeded and closes when the time defined by the gate length has elapsed. LEVel The gate opens when the gate level has been exceeded and closes when the signal level again falls below the gate level. OFF The gate is off.
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.EgateType)
		self._core.io.write(f'SENSe:SWEep:EGATe:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.EgateType:
		"""SCPI: [SENSe]:SWEep:EGATe:TYPE \n
		Snippet: value: enums.EgateType = driver.sense.sweep.egate.typePy.get() \n
		This command selects the gate type.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Optional pulsed phase noise measurement application. \n
			:return: type_py: No help available"""
		response = self._core.io.query_str(f'SENSe:SWEep:EGATe:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.EgateType)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BandCls:
	"""Band commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("band", core, parent)

	def set(self, band: enums.BandB) -> None:
		"""SCPI: [SENSe]:CORRection:CVL:BAND \n
		Snippet: driver.applications.k60Transient.sense.correction.cvl.band.set(band = enums.BandB.D) \n
		No command help available \n
			:param band: No help available
		"""
		param = Conversions.enum_scalar_to_str(band, enums.BandB)
		self._core.io.write(f'SENSe:CORRection:CVL:BAND {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.BandB:
		"""SCPI: [SENSe]:CORRection:CVL:BAND \n
		Snippet: value: enums.BandB = driver.applications.k60Transient.sense.correction.cvl.band.get() \n
		No command help available \n
			:return: band: No help available"""
		response = self._core.io.query_str(f'SENSe:CORRection:CVL:BAND?')
		return Conversions.str_to_scalar_enum(response, enums.BandB)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IdentCls:
	"""Ident commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ident", core, parent)

	def set(self, idn_format: enums.IdnFormat) -> None:
		"""SCPI: SYSTem:FORMat:IDENt \n
		Snippet: driver.system.formatPy.ident.set(idn_format = enums.IdnFormat.FSL) \n
		This command selects the response format to the *IDN? query. \n
			:param idn_format: LEGacy Format is compatible to R&S FSP/FSU/FSQ/FSG family. NEW | FSL R&S FSWP format Format is also compatible to the R&S FSL and R&S FSV family
		"""
		param = Conversions.enum_scalar_to_str(idn_format, enums.IdnFormat)
		self._core.io.write(f'SYSTem:FORMat:IDENt {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.IdnFormat:
		"""SCPI: SYSTem:FORMat:IDENt \n
		Snippet: value: enums.IdnFormat = driver.system.formatPy.ident.get() \n
		This command selects the response format to the *IDN? query. \n
			:return: idn_format: LEGacy Format is compatible to R&S FSP/FSU/FSQ/FSG family. NEW | FSL R&S FSWP format Format is also compatible to the R&S FSL and R&S FSV family"""
		response = self._core.io.query_str(f'SYSTem:FORMat:IDENt?')
		return Conversions.str_to_scalar_enum(response, enums.IdnFormat)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, auto_patt_search: enums.AutoManualMode) -> None:
		"""SCPI: [SENSe]:DDEMod:SEARch:SYNC:AUTO \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.search.sync.auto.set(auto_patt_search = enums.AutoManualMode.AUTO) \n
		This command links the pattern search to the type of signal. When a signal is marked as patterned, pattern search is
		switched on automatically. \n
			:param auto_patt_search: AUTO | MANual
		"""
		param = Conversions.enum_scalar_to_str(auto_patt_search, enums.AutoManualMode)
		self._core.io.write(f'SENSe:DDEMod:SEARch:SYNC:AUTO {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.AutoManualMode:
		"""SCPI: [SENSe]:DDEMod:SEARch:SYNC:AUTO \n
		Snippet: value: enums.AutoManualMode = driver.applications.k70Vsa.sense.ddemod.search.sync.auto.get() \n
		This command links the pattern search to the type of signal. When a signal is marked as patterned, pattern search is
		switched on automatically. \n
			:return: auto_patt_search: AUTO | MANual"""
		response = self._core.io.query_str(f'SENSe:DDEMod:SEARch:SYNC:AUTO?')
		return Conversions.str_to_scalar_enum(response, enums.AutoManualMode)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Types import DataType
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, dev_name: str, ms_sync_mode: enums.MsSyncMode) -> None:
		"""SCPI: [SENSe]:TRACe:IQ:SYNC:MODE \n
		Snippet: driver.sense.trace.iq.sync.mode.set(dev_name = '1', ms_sync_mode = enums.MsSyncMode.MASTer) \n
		No command help available \n
			:param dev_name: No help available
			:param ms_sync_mode: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('dev_name', dev_name, DataType.String), ArgSingle('ms_sync_mode', ms_sync_mode, DataType.Enum, enums.MsSyncMode))
		self._core.io.write(f'SENSe:TRACe:IQ:SYNC:MODE {param}'.rstrip())

	# noinspection PyTypeChecker
	def get(self) -> enums.MsSyncMode:
		"""SCPI: [SENSe]:TRACe:IQ:SYNC:MODE \n
		Snippet: value: enums.MsSyncMode = driver.sense.trace.iq.sync.mode.get() \n
		No command help available \n
			:return: ms_sync_mode: No help available"""
		response = self._core.io.query_str(f'SENSe:TRACe:IQ:SYNC:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.MsSyncMode)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AoffCls:
	"""Aoff commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("aoff", core, parent)

	def set(self, filterPy=repcap.FilterPy.Default) -> None:
		"""SCPI: [SENSe]:FILTer<n>:AOFF \n
		Snippet: driver.sense.filterPy.aoff.set(filterPy = repcap.FilterPy.Default) \n
		No command help available \n
			:param filterPy: optional repeated capability selector. Default value: Nr1 (settable in the interface 'FilterPy')
		"""
		filterPy_cmd_val = self._cmd_group.get_repcap_cmd_value(filterPy, repcap.FilterPy)
		self._core.io.write(f'SENSe:FILTer{filterPy_cmd_val}:AOFF')

	def set_with_opc(self, filterPy=repcap.FilterPy.Default, opc_timeout_ms: int = -1) -> None:
		filterPy_cmd_val = self._cmd_group.get_repcap_cmd_value(filterPy, repcap.FilterPy)
		"""SCPI: [SENSe]:FILTer<n>:AOFF \n
		Snippet: driver.sense.filterPy.aoff.set_with_opc(filterPy = repcap.FilterPy.Default) \n
		No command help available \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param filterPy: optional repeated capability selector. Default value: Nr1 (settable in the interface 'FilterPy')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:FILTer{filterPy_cmd_val}:AOFF', opc_timeout_ms)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GapCls:
	"""Gap commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("gap", core, parent)

	def set(self, seg_cap_gap_len: int) -> None:
		"""SCPI: [SENSe]:SWEep:SCAPture:GAP \n
		Snippet: driver.sense.sweep.scapture.gap.set(seg_cap_gap_len = 1) \n
		No command help available \n
			:param seg_cap_gap_len: No help available
		"""
		param = Conversions.decimal_value_to_str(seg_cap_gap_len)
		self._core.io.write(f'SENSe:SWEep:SCAPture:GAP {param}')

	def get(self) -> int:
		"""SCPI: [SENSe]:SWEep:SCAPture:GAP \n
		Snippet: value: int = driver.sense.sweep.scapture.gap.get() \n
		No command help available \n
			:return: seg_cap_gap_len: No help available"""
		response = self._core.io.query_str(f'SENSe:SWEep:SCAPture:GAP?')
		return Conversions.str_to_int(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, baseband_input_source: enums.BbInputSource, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:SELect \n
		Snippet: driver.applications.k70Vsa.inputPy.select.set(baseband_input_source = enums.BbInputSource.AIQ, inputIx = repcap.InputIx.Default) \n
		This command selects the signal source for measurements, i.e. it defines which connector is used to input data to the R&S
		FSWP. Tip: The I/Q data to be analyzed for VSA cannot only be measured by the R&S FSWP VSA application itself, it can
		also be imported to the application, provided it has the correct format. Furthermore, the analyzed I/Q data from the R&S
		FSWP VSA application can be exported for further analysis in external applications. For details, see the R&S FSWP I/Q
		Analyzer and I/Q Input User Manual. \n
			:param baseband_input_source: No help available
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.enum_scalar_to_str(baseband_input_source, enums.BbInputSource)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:SELect {param}')

	# noinspection PyTypeChecker
	def get(self, inputIx=repcap.InputIx.Default) -> enums.BbInputSource:
		"""SCPI: INPut<ip>:SELect \n
		Snippet: value: enums.BbInputSource = driver.applications.k70Vsa.inputPy.select.get(inputIx = repcap.InputIx.Default) \n
		This command selects the signal source for measurements, i.e. it defines which connector is used to input data to the R&S
		FSWP. Tip: The I/Q data to be analyzed for VSA cannot only be measured by the R&S FSWP VSA application itself, it can
		also be imported to the application, provided it has the correct format. Furthermore, the analyzed I/Q data from the R&S
		FSWP VSA application can be exported for further analysis in external applications. For details, see the R&S FSWP I/Q
		Analyzer and I/Q Input User Manual. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: baseband_input_source: No help available"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:SELect?')
		return Conversions.str_to_scalar_enum(response, enums.BbInputSource)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPyCls:
	"""FormatPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("formatPy", core, parent)

	def set(self, format_py: enums.DisplayFormat) -> None:
		"""SCPI: DISPlay:FORMat \n
		Snippet: driver.display.formatPy.set(format_py = enums.DisplayFormat.SINGle) \n
		This command determines which tab is displayed. \n
			:param format_py: SPLit Displays the MultiView tab with an overview of all active channels (See 'R&S MultiView') . SINGle Displays the measurement channel that was previously focused.
		"""
		param = Conversions.enum_scalar_to_str(format_py, enums.DisplayFormat)
		self._core.io.write(f'DISPlay:FORMat {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.DisplayFormat:
		"""SCPI: DISPlay:FORMat \n
		Snippet: value: enums.DisplayFormat = driver.display.formatPy.get() \n
		This command determines which tab is displayed. \n
			:return: format_py: SPLit Displays the MultiView tab with an overview of all active channels (See 'R&S MultiView') . SINGle Displays the measurement channel that was previously focused."""
		response = self._core.io.query_str(f'DISPlay:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.DisplayFormat)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DisplayCls:
	"""Display commands group definition. 5 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("display", core, parent)

	@property
	def fpanel(self):
		"""fpanel commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_fpanel'):
			from .Fpanel import FpanelCls
			self._fpanel = FpanelCls(self._core, self._cmd_group)
		return self._fpanel

	@property
	def update(self):
		"""update commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_update'):
			from .Update import UpdateCls
			self._update = UpdateCls(self._core, self._cmd_group)
		return self._update

	@property
	def lock(self):
		"""lock commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_lock'):
			from .Lock import LockCls
			self._lock = LockCls(self._core, self._cmd_group)
		return self._lock

	@property
	def message(self):
		"""message commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_message'):
			from .Message import MessageCls
			self._message = MessageCls(self._core, self._cmd_group)
		return self._message

	def clone(self) -> 'DisplayCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DisplayCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MdescriptionCls:
	"""Mdescription commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mdescription", core, parent)

	def set(self, description: str) -> None:
		"""SCPI: SYSTem:LXI:MDEScription \n
		Snippet: driver.system.lxi.mdescription.set(description = '1') \n
		This command defines the 'LAN' instrument description. \n
			:param description: String containing the instrument description.
		"""
		param = Conversions.value_to_quoted_str(description)
		self._core.io.write(f'SYSTem:LXI:MDEScription {param}')

	def get(self) -> str:
		"""SCPI: SYSTem:LXI:MDEScription \n
		Snippet: value: str = driver.system.lxi.mdescription.get() \n
		This command defines the 'LAN' instrument description. \n
			:return: description: String containing the instrument description."""
		response = self._core.io.query_str(f'SYSTem:LXI:MDEScription?')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PortsCls:
	"""Ports commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ports", core, parent)

	def set(self, port_type: int) -> None:
		"""SCPI: [SENSe]:MIXer:PORTs \n
		Snippet: driver.sense.mixer.ports.set(port_type = 1) \n
		This command queries the connected mixer type. Currently, only three-port mixers are supported. \n
			:param port_type: 2 | 3 2 Two-port mixer. 3 Three-port mixer.
		"""
		param = Conversions.decimal_value_to_str(port_type)
		self._core.io.write(f'SENSe:MIXer:PORTs {param}')

	def get(self) -> int:
		"""SCPI: [SENSe]:MIXer:PORTs \n
		Snippet: value: int = driver.sense.mixer.ports.get() \n
		This command queries the connected mixer type. Currently, only three-port mixers are supported. \n
			:return: port_type: 2 | 3 2 Two-port mixer. 3 Three-port mixer."""
		response = self._core.io.query_str(f'SENSe:MIXer:PORTs?')
		return Conversions.str_to_int(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FpeaksCls:
	"""Fpeaks commands group definition. 8 total commands, 8 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fpeaks", core, parent)

	@property
	def immediate(self):
		"""immediate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_immediate'):
			from .Immediate import ImmediateCls
			self._immediate = ImmediateCls(self._core, self._cmd_group)
		return self._immediate

	@property
	def count(self):
		"""count commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_count'):
			from .Count import CountCls
			self._count = CountCls(self._core, self._cmd_group)
		return self._count

	@property
	def x(self):
		"""x commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_x'):
			from .X import XCls
			self._x = XCls(self._core, self._cmd_group)
		return self._x

	@property
	def y(self):
		"""y commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_y'):
			from .Y import YCls
			self._y = YCls(self._core, self._cmd_group)
		return self._y

	@property
	def sort(self):
		"""sort commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sort'):
			from .Sort import SortCls
			self._sort = SortCls(self._core, self._cmd_group)
		return self._sort

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def listPy(self):
		"""listPy commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_listPy'):
			from .ListPy import ListPyCls
			self._listPy = ListPyCls(self._core, self._cmd_group)
		return self._listPy

	@property
	def annotation(self):
		"""annotation commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_annotation'):
			from .Annotation import AnnotationCls
			self._annotation = AnnotationCls(self._core, self._cmd_group)
		return self._annotation

	def clone(self) -> 'FpeaksCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FpeaksCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StandardCls:
	"""Standard commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("standard", core, parent)

	def set(self, standard: str, subBlock=repcap.SubBlock.Default) -> None:
		"""SCPI: [SENSe]:ESPectrum<sb>:PRESet[:STANdard] \n
		Snippet: driver.sense.espectrum.preset.standard.set(standard = '1', subBlock = repcap.SubBlock.Default) \n
		No command help available \n
			:param standard: No help available
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
		"""
		param = Conversions.value_to_quoted_str(standard)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		self._core.io.write(f'SENSe:ESPectrum{subBlock_cmd_val}:PRESet:STANdard {param}')

	def get(self, subBlock=repcap.SubBlock.Default) -> str:
		"""SCPI: [SENSe]:ESPectrum<sb>:PRESet[:STANdard] \n
		Snippet: value: str = driver.sense.espectrum.preset.standard.get(subBlock = repcap.SubBlock.Default) \n
		No command help available \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:return: standard: No help available"""
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		response = self._core.io.query_str(f'SENSe:ESPectrum{subBlock_cmd_val}:PRESet:STANdard?')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HspeedCls:
	"""Hspeed commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hspeed", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:POWer:HSPeed \n
		Snippet: driver.sense.power.hspeed.set(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:POWer:HSPeed {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:POWer:HSPeed \n
		Snippet: value: bool = driver.sense.power.hspeed.get() \n
		No command help available \n
			:return: state: No help available"""
		response = self._core.io.query_str(f'SENSe:POWer:HSPeed?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TopCls:
	"""Top commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("top", core, parent)

	def set(self, top: float) -> None:
		"""SCPI: HCOPy:PAGE:MARGin:TOP \n
		Snippet: driver.hardCopy.page.margin.top.set(top = 1.0) \n
		This command defines the margin at the top of the printout page on which no elements are printed. The margins are defined
		according to method RsFswp.HardCopy.Page.Margin.Unit.set. \n
			:param top: No help available
		"""
		param = Conversions.decimal_value_to_str(top)
		self._core.io.write(f'HCOPy:PAGE:MARGin:TOP {param}')

	def get(self) -> float:
		"""SCPI: HCOPy:PAGE:MARGin:TOP \n
		Snippet: value: float = driver.hardCopy.page.margin.top.get() \n
		This command defines the margin at the top of the printout page on which no elements are printed. The margins are defined
		according to method RsFswp.HardCopy.Page.Margin.Unit.set. \n
			:return: top: No help available"""
		response = self._core.io.query_str(f'HCOPy:PAGE:MARGin:TOP?')
		return Conversions.str_to_float(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SymbolRateCls:
	"""SymbolRate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("symbolRate", core, parent)

	def get(self) -> float:
		"""SCPI: [SENSe]:SRATe \n
		Snippet: value: float = driver.sense.symbolRate.get() \n
		No command help available \n
			:return: sample_rate: No help available"""
		response = self._core.io.query_str(f'SENSe:SRATe?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, result: enums.NoiseFigureLimit, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:TYPE \n
		Snippet: driver.applications.k30NoiseFigure.calculate.limit.typePy.set(result = enums.NoiseFigureLimit.ENR, window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command configures a limit line for a particular result type. \n
			:param result: NOISe | GAIN | TEMPerature | YFACtor | ENR | PHOT | PCOLd GAIN Assigns the limit line to 'gain' reuslts. NOISe Assigns the limit line to 'noise figure' results. PCOLd Assigns the limit line to power (cold) results. PHOT Assigns the limit line to power (hot) results. TEMPerature Assigns the limit line to 'noise temperature' results. YFACtor Assigns the limit line to 'y-factor' results.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
		"""
		param = Conversions.enum_scalar_to_str(result, enums.NoiseFigureLimit)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> enums.NoiseFigureLimit:
		"""SCPI: CALCulate<n>:LIMit<li>:TYPE \n
		Snippet: value: enums.NoiseFigureLimit = driver.applications.k30NoiseFigure.calculate.limit.typePy.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command configures a limit line for a particular result type. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: result: NOISe | GAIN | TEMPerature | YFACtor | ENR | PHOT | PCOLd GAIN Assigns the limit line to 'gain' reuslts. NOISe Assigns the limit line to 'noise figure' results. PCOLd Assigns the limit line to power (cold) results. PHOT Assigns the limit line to power (hot) results. TEMPerature Assigns the limit line to 'noise temperature' results. YFACtor Assigns the limit line to 'y-factor' results."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.NoiseFigureLimit)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Power_Vsupply: float: No parameter help available
			- Power_Vtune: float: No parameter help available
			- Power_Vaux: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_float('Power_Vsupply'),
			ArgStruct.scalar_float('Power_Vtune'),
			ArgStruct.scalar_float('Power_Vaux')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Power_Vsupply: float = None
			self.Power_Vtune: float = None
			self.Power_Vaux: float = None

	def get(self) -> GetStruct:
		"""SCPI: SOURce:POWer:SEQuence:RESult \n
		Snippet: value: GetStruct = driver.source.power.sequence.result.get() \n
		This command queries the actually measured power (U*I) on the DC power sources.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn on DC power sources (method RsFswp.Applications.K30_NoiseFigure.Source.Voltage.State.set) . \n
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		return self._core.io.query_struct(f'SOURce:POWer:SEQuence:RESult?', self.__class__.GetStruct())



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Utilities import trim_str_response
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ListPyCls:
	"""ListPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("listPy", core, parent)

	def get(self, store=repcap.Store.Default) -> str:
		"""SCPI: MMEMory:STORe<n>:LIST \n
		Snippet: value: str = driver.massMemory.store.listPy.get(store = repcap.Store.Default) \n
		This command exports the SEM and spurious emission list evaluation to a file. The file format is *.dat. \n
			:param store: optional repeated capability selector. Default value: Pos1 (settable in the interface 'Store')
			:return: filename: String containing the path and name of the target file."""
		store_cmd_val = self._cmd_group.get_repcap_cmd_value(store, repcap.Store)
		response = self._core.io.query_str(f'MMEMory:STORe{store_cmd_val}:LIST?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, signal_type: enums.DdemSignalType) -> None:
		"""SCPI: [SENSe]:DDEMod:SIGNal[:VALue] \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.signal.value.set(signal_type = enums.DdemSignalType.BURSted) \n
		No command help available \n
			:param signal_type: CONTinuous | BURSted
		"""
		param = Conversions.enum_scalar_to_str(signal_type, enums.DdemSignalType)
		self._core.io.write(f'SENSe:DDEMod:SIGNal:VALue {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.DdemSignalType:
		"""SCPI: [SENSe]:DDEMod:SIGNal[:VALue] \n
		Snippet: value: enums.DdemSignalType = driver.applications.k70Vsa.sense.ddemod.signal.value.get() \n
		No command help available \n
			:return: signal_type: CONTinuous | BURSted"""
		response = self._core.io.query_str(f'SENSe:DDEMod:SIGNal:VALue?')
		return Conversions.str_to_scalar_enum(response, enums.DdemSignalType)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MaccuracyCls:
	"""Maccuracy commands group definition. 110 total commands, 10 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("maccuracy", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def default(self):
		"""default commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_default'):
			from .Default import DefaultCls
			self._default = DefaultCls(self._core, self._cmd_group)
		return self._default

	@property
	def cfError(self):
		"""cfError commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_cfError'):
			from .CfError import CfErrorCls
			self._cfError = CfErrorCls(self._core, self._cmd_group)
		return self._cfError

	@property
	def evm(self):
		"""evm commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_evm'):
			from .Evm import EvmCls
			self._evm = EvmCls(self._core, self._cmd_group)
		return self._evm

	@property
	def fdError(self):
		"""fdError commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_fdError'):
			from .FdError import FdErrorCls
			self._fdError = FdErrorCls(self._core, self._cmd_group)
		return self._fdError

	@property
	def freqError(self):
		"""freqError commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_freqError'):
			from .FreqError import FreqErrorCls
			self._freqError = FreqErrorCls(self._core, self._cmd_group)
		return self._freqError

	@property
	def merror(self):
		"""merror commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_merror'):
			from .Merror import MerrorCls
			self._merror = MerrorCls(self._core, self._cmd_group)
		return self._merror

	@property
	def ooffset(self):
		"""ooffset commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_ooffset'):
			from .Ooffset import OoffsetCls
			self._ooffset = OoffsetCls(self._core, self._cmd_group)
		return self._ooffset

	@property
	def perror(self):
		"""perror commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_perror'):
			from .Perror import PerrorCls
			self._perror = PerrorCls(self._core, self._cmd_group)
		return self._perror

	@property
	def rho(self):
		"""rho commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_rho'):
			from .Rho import RhoCls
			self._rho = RhoCls(self._core, self._cmd_group)
		return self._rho

	def clone(self) -> 'MaccuracyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MaccuracyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DefaultCls:
	"""Default commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("default", core, parent)

	def set(self, alignment: enums.AdjustAlignment, window=repcap.Window.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: CALCulate<n>:TRACe<t>:ADJust:ALIGnment[:DEFault] \n
		Snippet: driver.applications.k70Vsa.calculate.trace.adjust.alignment.default.set(alignment = enums.AdjustAlignment.CENTer, window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This command defines where the reference point is to appear in the result range. \n
			:param alignment: LEFT | CENTer | RIGHt LEFT The reference point is at the start of the result range. CENTer The reference point is in the middle of the result range. RIGHt The reference point is displayed at the end of the result range.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.enum_scalar_to_str(alignment, enums.AdjustAlignment)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'CALCulate{window_cmd_val}:TRACe{trace_cmd_val}:ADJust:ALIGnment:DEFault {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, trace=repcap.Trace.Default) -> enums.AdjustAlignment:
		"""SCPI: CALCulate<n>:TRACe<t>:ADJust:ALIGnment[:DEFault] \n
		Snippet: value: enums.AdjustAlignment = driver.applications.k70Vsa.calculate.trace.adjust.alignment.default.get(window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This command defines where the reference point is to appear in the result range. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: alignment: LEFT | CENTer | RIGHt LEFT The reference point is at the start of the result range. CENTer The reference point is in the middle of the result range. RIGHt The reference point is displayed at the end of the result range."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:TRACe{trace_cmd_val}:ADJust:ALIGnment:DEFault?')
		return Conversions.str_to_scalar_enum(response, enums.AdjustAlignment)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Utilities import trim_str_response
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IdnCls:
	"""Idn commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("idn", core, parent)

	def get(self, inputIx=repcap.InputIx.Default) -> str:
		"""SCPI: INPut<ip>:IQ:OSC:IDN \n
		Snippet: value: str = driver.applications.iqAnalyzer.inputPy.iq.osc.idn.get(inputIx = repcap.InputIx.Default) \n
		No command help available \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: identification: No help available"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:IQ:OSC:IDN?')
		return trim_str_response(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, state: bool, gapChannel=repcap.GapChannel.Default) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:FILTer[:STATe]:GAP<gap>[:AUTO] \n
		Snippet: driver.sense.power.achannel.filterPy.state.gap.auto.set(state = False, gapChannel = repcap.GapChannel.Default) \n
		No command help available \n
			:param state: No help available
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
		"""
		param = Conversions.bool_to_str(state)
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		self._core.io.write(f'SENSe:POWer:ACHannel:FILTer:STATe:GAP{gapChannel_cmd_val}:AUTO {param}')



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StartCls:
	"""Start commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("start", core, parent)

	def get(self, window=repcap.Window.Default) -> int:
		"""SCPI: CALCulate<n>:DSP:RESult:RRANge:CURRent:BURSt:STARt \n
		Snippet: value: int = driver.applications.k70Vsa.calculate.dsp.result.rrange.current.burst.start.get(window = repcap.Window.Default) \n
		Queries the burst start in the current result range as an offset to the capture buffer start. Tip: To determine the
		capture buffer start, use the method RsFswp.Applications.K70_Vsa.Display.Window.Trace.X.Scale.Start.get_ command for a
		window with a capture buffer display. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: start: Offset in symbols from the capture buffer start. Unit: sym"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:DSP:RESult:RRANge:CURRent:BURSt:STARt?')
		return Conversions.str_to_int(response)
